==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/pt/information.php <==
<?php
return array (
  '<strong>CronJob</strong> Status' => '<strong>Estado</strong> dos Cronjobs',
  '<strong>Queue</strong> Status' => '<strong>Estado</strong> da Fila de espera',
  'About HumHub' => 'Sobre o HumHub',
  'Assets' => '',
  'Background Jobs' => 'Tarefas em Segundo Plano',
  'Checking HumHub software prerequisites.' => 'A verificar os pré-requisitos de software do HumHub..',
  'Current limit is: {currentLimit}' => '',
  'Database' => 'Base de dados',
  'Database collation' => '',
  'Database connection time: {dbTime} - Configured time zone: {time}' => 'Hora de ligação à Base de dados: {dbTime} - Fuso horário configurado: {time}',
  'Database driver - {driver}' => '',
  'Database migration results:' => 'Resultados da migração de base de dados:',
  'Delayed' => 'Atrasado',
  'Displaying {count} entries per page.' => 'A mostrar {count,plural,=0{nenhuma entrada} =1{uma entrada} other{# entradas}} por página.',
  'Done' => 'Concluído',
  'Driver' => 'Driver',
  'Dynamic Config' => '',
  'Error' => 'Erro',
  'Flush entries' => 'Limpar entradas',
  'HumHub is currently in debug mode. Disable it when running on production!' => 'O HumHub está em modo de debug. Desactiva o modo debug quando estiver a correr em produção!',
  'ICU Data Version ({version})' => '',
  'ICU Data {icuMinVersion} or higher is required' => '',
  'ICU Version ({version})' => '',
  'ICU {icuMinVersion} or higher is required' => '',
  'Increase memory limit in {fileName}' => '',
  'Info' => 'Informação',
  'Install {phpExtension} Extension' => '',
  'Install {phpExtension} Extension for APC Caching' => '',
  'Install {phpExtension} Extension for DB Caching' => '',
  'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
  'Last run (daily):' => 'Última execução (diária):',
  'Last run (hourly):' => 'Última execução (hora-a-hora):',
  'Licences' => 'Licenças',
  'Logging' => 'Registos',
  'Make {filePath} writable for the Webserver/PHP!' => '',
  'Memory Limit ({memoryLimit})' => '',
  'Minimum Version {minVersion}' => '',
  'Module Directory' => '',
  'Multibyte String Functions' => '',
  'Never' => 'Nunca',
  'Optional' => '',
  'Other' => 'Outrꜵ',
  'Permissions' => 'Permissões',
  'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Por favor consulta a documentação para configurar cronjobs e tarefeiros da fila de espera.',
  'Prerequisites' => 'Pré-requisitos',
  'Profile Image' => '',
  'Queue successfully cleared.' => 'Fila de espera limpa com sucesso.',
  'Re-Run tests' => 'Repetir testes',
  'Recommended collation is {collation}' => '',
  'Recommended collation is {collation} for the tables: {tables}' => '',
  'Recommended engine is {engine} for the tables: {tables}' => '',
  'Reserved' => 'Reservado',
  'Runtime' => '',
  'Search index rebuild in progress.' => 'Índice de pesquisa em reconstrução..',
  'Search term...' => 'Elemento a procurar...',
  'See installation manual for more details.' => 'Consulta o manual de instalação para mais detalhes.',
  'Select category..' => 'Escolhe a categoria..',
  'Select day' => 'Escolhe o dia',
  'Select level...' => 'Escolhe o nível',
  'Settings' => 'Definições',
  'Supported drivers: {drivers}' => '',
  'Table collations' => '',
  'Table engines' => '',
  'The current main HumHub database name is ' => 'O nome da base de dados principal do HumHub é',
  'There is a new update available! (Latest version: %version%)' => 'Há uma nova actualização disponível! (Latest version: %version%)',
  'This HumHub installation is up to date!' => 'Esta instalação do HumHub está actualizada!',
  'Time zone' => '',
  'Total {count} entries found.' => '{count,plural,=0{Não foi encontrada nenhuma entrada} =1{Foi encontrada uma entrada} other{Foram encontradas # entradas}} no total.',
  'Trace' => 'Rasto',
  'Uploads' => '',
  'Varying table engines are not supported.' => '',
  'Version' => '',
  'Waiting' => 'Aguardando',
  'Warning' => 'Aviso',
  '{imageExtension} Support' => '',
  '{phpExtension} Extension' => '',
  '{phpExtension} Support' => '',
);

==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/admin/messages/pt/information.php <==
<?php
return array (
  '<strong>CronJob</strong> Status' => 'Estado dos <strong>Cronjobs</strong>',
  '<strong>Queue</strong> Status' => 'Estado da <strong>Fila de Espera</strong>',
  'About HumHub' => 'Sobre o HumHub',
  'Assets' => 'Ativos',
  'Background Jobs' => 'Tarefas em Segundo Plano',
  'Checking HumHub software prerequisites.' => 'A verificar os pré-requisitos de software do HumHub..',
  'Current limit is: {currentLimit}' => 'O limite atual é: {currentLimit}',
  'Database' => 'Base de dados',
  'Database collation' => 'Código de caracteres da Base de Dados',
  'Database connection time: {dbTime} - Configured time zone: {time}' => 'Hora de ligação à Base de dados: {dbTime} - Fuso horário configurado: {time}',
  'Database driver - {driver}' => 'Controlador da Base de Dados - {driver}',
  'Database migration results:' => 'Resultados da migração de base de dados:',
  'Delayed' => 'Atrasado',
  'Displaying {count} entries per page.' => 'A mostrar {count,plural,=0{nenhuma entrada} =1{uma entrada} other{# entradas}} por página.',
  'Done' => 'Concluído',
  'Driver' => 'Controlador',
  'Dynamic Config' => 'Configuração Dinâmica',
  'Error' => 'Erro',
  'Flush entries' => 'Limpar entradas',
  'HumHub is currently in debug mode. Disable it when running on production!' => 'O HumHub está em modo de debug. Desativa o modo debug quando em produção!',
  'ICU Data Version ({version})' => 'Versão dos Dados ICU ({version})',
  'ICU Data {icuMinVersion} or higher is required' => 'Requerida a Versão de Dados ICU {icuMinVersion} ou superior',
  'ICU Version ({version})' => 'Versão ICU ({version})',
  'ICU {icuMinVersion} or higher is required' => 'Requerida a Versão ICU {icuMinVersion} ou superior',
  'Increase memory limit in {fileName}' => 'Aumenta o limete de memória em {fileName}',
  'Info' => 'Informação',
  'Install {phpExtension} Extension' => 'Instalar a Extensão PHP {phpExtension}',
  'Install {phpExtension} Extension for APC Caching' => 'Instalar a Extensão PHP {phpExtension} para  cache APC',
  'Install {phpExtension} Extension for DB Caching' => 'Instalar a Extensão PHP {phpExtension} para cache DB',
  'Install {phpExtension} Extension for e-mail S/MIME support.' => 'Instalar a Extensão PHP {phpExtension}  para suporte de e-mail S/MIME.',
  'Last run (daily):' => 'Última execução (diária):',
  'Last run (hourly):' => 'Última execução (hora-a-hora):',
  'Licences' => 'Licenças',
  'Logging' => 'Registos',
  'Make {filePath} writable for the Webserver/PHP!' => '',
  'Memory Limit ({memoryLimit})' => '',
  'Minimum Version {minVersion}' => '',
  'Module Directory' => '',
  'Multibyte String Functions' => '',
  'Never' => 'Nunca',
  'Optional' => '',
  'Other' => 'Outrꜵ',
  'Permissions' => 'Permissões',
  'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Por favor consulta a documentação para configurar cronjobs e tarefeiros da fila de espera.',
  'Prerequisites' => 'Pré-requisitos',
  'Profile Image' => '',
  'Queue successfully cleared.' => 'Fila de espera limpa com sucesso.',
  'Re-Run tests' => 'Repetir testes',
  'Recommended collation is {collation}' => '',
  'Recommended collation is {collation} for the tables: {tables}' => '',
  'Recommended engine is {engine} for the tables: {tables}' => '',
  'Reserved' => 'Reservado',
  'Runtime' => '',
  'Search index rebuild in progress.' => 'Índice de pesquisa em reconstrução..',
  'Search term...' => 'Elemento a procurar...',
  'See installation manual for more details.' => 'Consulta o manual de instalação para mais detalhes.',
  'Select category..' => 'Escolhe a categoria..',
  'Select day' => 'Escolhe o dia',
  'Select level...' => 'Escolhe o nível',
  'Settings' => 'Definições',
  'Supported drivers: {drivers}' => '',
  'Table collations' => '',
  'Table engines' => '',
  'The current main HumHub database name is ' => 'O nome da base de dados principal do HumHub é',
  'There is a new update available! (Latest version: %version%)' => 'Há uma nova actualização disponível! (Latest version: %version%)',
  'This HumHub installation is up to date!' => 'Esta instalação do HumHub está actualizada!',
  'Time zone' => '',
  'Total {count} entries found.' => '{count,plural,=0{Não foi encontrada nenhuma entrada} =1{Foi encontrada uma entrada} other{Foram encontradas # entradas}} no total.',
  'Trace' => 'Rasto',
  'Uploads' => '',
  'Varying table engines are not supported.' => '',
  'Version' => '',
  'Waiting' => 'Aguardando',
  'Warning' => 'Aviso',
  '{imageExtension} Support' => '',
  '{phpExtension} Extension' => '',
  '{phpExtension} Support' => '',
);
